<div class="{{ widget }}" id="{{ widget }}">
	<div class="widgetIcons">
		<div class="widgetIcon">
			<i class="fas fa-calendar-alt"></i>
		</div>
		<div class="widgetIcon" id="widgetSettings_{{ widget }}">
			<i class="fas fa-cog"></i>
		</div>
	</div>
	<div>
		
	</div>
</div>