{
	"name": "{{ skillName }}",
	"version": "0.0.1",
	"icon": "fab fa-battle-net",
	"category": "undefined",
	"author": "{{ username }}",
	"maintainers": [],
	"desc": "{{ description }}",
	"aliceMinVersion": "1.0.0",
	"pipRequirements": [
	{%- for pipRequirement in pipRequirements %}
		"{{ pipRequirement }}"{{ "," if not loop.last -}}{{ "\n	" if loop.last }}
	{%- endfor %}],
	"systemRequirements":  [
	{%- for systemRequirement in systemRequirements %}
		"{{ systemRequirement }}"{{ "," if not loop.last -}}{{ "\n	" if loop.last }}
	{%- endfor %}],
	"conditions": {
		"lang": [
		{%- for lang in langs %}
			"{{ lang }}"{{ "," if not loop.last -}}{{ "\n		" if loop.last }}
		{%- endfor %}]
	}
}
